package org.apache.commons.net.ftp;

import java.io.IOException;
import osid.filing.*; 
import java.io.PrintWriter;

/**
 * This is the FTP client factory that connects to the ftp site and returns the client.
 */
public final class FTPClientFactory
{
    private static final FTPFileListParser __fileListParser = new DefaultFTPFileListParser(); 
    private FTPClient client = null; 
    
    private String host = null;
    private String username = null;
    private String password = null;
   
   
    public FTPClientFactory(String host, String username, String password) {
        this.host = host;
        this.username = username;
        this.password = password;
    }
 
    public FTPClient createClient()
        throws FilingException
    {
        
        try
        {
            this.client = new FTPClient();
            client.connect(this.host);
            client.login(this.username, this.password);
            if (FTPReply.NOT_LOGGED_IN == client.getReplyCode()) {
                this.client = null;
                throw new FilingException(FilingException.PERMISSION_DENIED);
            }     
            client.enterLocalPassiveMode();
        //   client.addProtocolCommandListener(new PrintCommandListener(
        //                                   new PrintWriter(System.out)));
        }
        catch (IOException e) {
            this.client = null;
            throw new FilingException(FilingException.IO_ERROR);
        }
        return this.client;
    }
}  



